==> moodle-1.4.3-pgsql.tgz: moodle/lang/tr/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.4 (2004083100)


$string['addresource'] = 'Kaynak ekle';
$string['chooseafile'] = 'Anket veya bir dosya ykle';
$string['chooseparameter'] = 'parametre se';
$string['directlink'] = 'Bu dosyaya direkt link';
$string['directoryinfo'] = 'Seilmi dizindeki tm dizinler gsterilir.';
$string['display'] = 'Pencere';
$string['editingaresource'] = 'Kaynak dzenleme';
$string['encryptedcode'] = 'ifrelenmi kod';
$string['example'] = 'rnek';
$string['exampleurl'] = 'http://www.ornek.com/ornekdizin/dosya.html';
$string['filename'] = 'Dosya ad';
$string['filtername'] = 'Kaynak Adlar Otomatik-Linkleme';
$string['fulltext'] = 'Tam metin';
$string['htmlfragment'] = 'HTML paras';
$string['maindirectory'] = 'Ana dosya dizini';
$string['modulename'] = 'Kaynak';
$string['modulenameplural'] = 'Kaynaklar';
$string['neverseen'] = 'Grlmedi';
$string['newdirectories'] = 'Dizin linklerini gster';
$string['newfullscreen'] = 'Ekran kapla';
$string['newheight'] = 'Varsaylan pencere ykseklii (pixel olarak)';
$string['newlocation'] = 'Adres ubuunu gster';
$string['newmenubar'] = 'Men ubuunu gster';
$string['newresizable'] = 'Pencerenin yeniden boyutlandrlmasna izin ver';
$string['newscrollbars'] = 'Pencerenin kaydrlmasna izin ver';
$string['newstatus'] = 'Durum ubuunu gster';
$string['newtoolbar'] = 'Ara ubuunu gster';
$string['newwidth'] = 'Varsaylan pencere genilii (pixel olarak)';
$string['newwindow'] = 'Yeni pencere';
$string['newwindowopen'] = 'Bu kayna yeni bir pencerede a';
$string['note'] = 'Not';
$string['notefile'] = 'Bu listede grlecek daha ok dosya yklemek iin 
<A HREF=\"$a\">Dosya Yneticisini</A> kullannz.';
$string['notypechosen'] = 'Bir tr semelisiniz.  Geri dmesini kullanarak tekrar deneyiniz.';
$string['pagedisplay'] = 'Bu kayna u anki pencerede gster';
$string['pagewindow'] = 'Ayn pencere';
$string['parameter'] = 'Parametre';
$string['parameters'] = 'Parametreler';
$string['popupresource'] = 'Bu kaynak alr pencere olarak grnsn';
$string['popupresourcelink'] = 'Olmadysa buray tkla: $a';
$string['resourcetype'] = 'Kaynak tr';
$string['resourcetype1'] = 'Referans';
$string['resourcetype2'] = 'Web Sayfas';
$string['resourcetype3'] = 'Yklenmi Dosya';
$string['resourcetype4'] = 'Sade Metin';
$string['resourcetype5'] = 'Web Balants';
$string['resourcetype6'] = 'HTML Metni';
$string['resourcetype9'] = 'Dizin';
$string['resourcetypedirectory'] = 'Bir dizin gster';
$string['resourcetypefile'] = 'Bir dosyaya veya web sitesine balant';
$string['resourcetypehtml'] = 'Bir web sayfas olutur';
$string['resourcetypelabel'] = 'Yeni bir Etiket ekle';
$string['resourcetypetext'] = 'Dz metin dosyas olutur';
$string['searchweb'] = 'Web sayfasn ara';
$string['variablename'] = 'Deiken ad';

?>

==> moodle-1.5-pgsql.tgz: moodle/lang/tr/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.5 ALPHA (2005042300)


$string['addresource'] = 'Kaynak ekle';
$string['chooseafile'] = 'Se veya bir dosya ykle';
$string['chooseparameter'] = 'parametre se';
$string['directlink'] = 'Bu dosyaya direkt link';
$string['directoryinfo'] = 'Seilmi dizindeki tm dosyalar gsterilir.';
$string['display'] = 'Pencere';
$string['editingaresource'] = 'Kaynak dzenleme';
$string['encryptedcode'] = 'ifrelenmi kod';
$string['example'] = 'rnek';
$string['exampleurl'] = 'http://www.ornek.com/ornekdizin/dosya.html';
$string['filename'] = 'Dosya ad';
$string['filtername'] = 'Kaynak Adlar Otomatik-Linkleme';
$string['frameifpossible'] = 'Site navigasyonunu grnr klmak iin kaynak frame iinde grnsn';
$string['fulltext'] = 'Tam metin';
$string['htmlfragment'] = 'HTML paras';
$string['localfile'] = 'Yerel dosya';
$string['localfilechoose'] = 'Yerel bir dosya sein (CD-ROM)';
$string['localfilehelp'] = 'Yerel dosyalar gsterirken yardm et';
$string['localfileselect'] = 'Bu dosya yolunu se';
$string['maindirectory'] = 'Ana dosya dizini';
$string['modulename'] = 'Kaynak';
$string['modulenameplural'] = 'Kaynaklar';
$string['neverseen'] = 'Grlmedi';
$string['newdirectories'] = 'Dizin linklerini gster';
$string['newfullscreen'] = 'Ekran kapla';
$string['newheight'] = 'Varsaylan pencere ykseklii (pixel olarak)';
$string['newlocation'] = 'Adres ubuunu gster';
$string['newmenubar'] = 'Men ubuunu gster';
$string['newresizable'] = 'Pencerenin yeniden boyutlandrlmasna izin ver';
$string['newscrollbars'] = 'Pencerenin kaydrlmasna izin ver';
$string['newstatus'] = 'Durum ubuunu gster';
$string['newtoolbar'] = 'Ara ubuunu gster';
$string['newwidth'] = 'Varsaylan pencere genilii (pixel olarak)';
$string['newwindow'] = 'Yeni pencere';
$string['newwindowopen'] = 'Bu kayna yeni bir pencerede a';
$string['notallowedlocalfileaccess'] = 'u anda yerel dosyalara eriim engellendiinden dolay bu kaynaa ulalamaz.';
$string['note'] = 'Not';
$string['notefile'] = 'Bu kursa daha fazla dosya yklemek iin (bu listede grnecek)
<A HREF=\"$a\">Dosya Yneticisini</A> kullannz.';
$string['notypechosen'] = 'Bir tr semelisiniz. Geri dmesini kullanarak tekrar deneyiniz.';
$string['pagedisplay'] = 'Bu kayna u anki pencerede gster';
$string['pagewindow'] = 'Ayn pencere';
$string['parameter'] = 'Parametre';
$string['parameters'] = 'Parametreler';
$string['popupresource'] = 'Bu kaynak alr pencere olarak grnsn';
$string['popupresourcelink'] = 'Olmadysa buray tkla: $a';
$string['resourcetype'] = 'Kaynak tr';
$string['resourcetype1'] = 'Referans';
$string['resourcetype2'] = 'Web Sayfas';
$string['resourcetype3'] = 'Yklenmi Dosya';
$string['resourcetype4'] = 'Dz Metin';
$string['resourcetype5'] = 'Web Balants';
$string['resourcetype6'] = 'HTML Metni';
$string['resourcetype7'] = 'Program';
$string['resourcetype9'] = 'Dizin';
$string['resourcetypedirectory'] = 'Bir dizin gster';
$string['resourcetypefile'] = 'Bir dosya/siteye balant';
$string['resourcetypehtml'] = 'Bir web sayfas olutur';
$string['resourcetypelabel'] = 'Yeni bir etiket ekle';
$string['resourcetypetext'] = 'Dzmetin dosyas olutur';
$string['searchweb'] = 'Web sayfasn ara';
$string['serverurl'] = 'Sunucu adresi ($a->wwwroot)';
$string['variablename'] = 'Deiken ad';

?>
